@@ -29,7 +29,6 @@ globalVariables(
 .timeIdToDate <- antaresRead:::.timeIdToDate
 .getTimeId <- antaresRead:::.getTimeId
 .mergeByRef <- antaresRead:::.mergeByRef
-.requireRhdf5_Antares <- antaresRead:::.requireRhdf5_Antares
 .checkColumns <- antaresProcessing:::.checkColumns
 .checkAttrs <- antaresProcessing:::.checkAttrs
 
@@ -279,70 +278,50 @@ colorsVars <- unique(rbindlist(list(colorsVars, col_fr)))
   return(resList)
 }
 
-#' edit h5 file only for TEST 
-#' currently only for hourly data and areas
-#' 
-#' @param pathH5 path H5 file
-#' @param area character
-#' @param timeId timeId to change
-#' @param antVar antares Variable to change
-#' @param newValue the newValue
-#' 
-#' @noRd
-.h5Antares_edit_variable <- function(pathH5 = NULL, area = NULL, timeId = 1, antVar = NULL, newValue = NULL, mcYear = NULL, link = NULL){
-  
-  if (!is.null(area) & !is.null(link)){
-    stop("area and link must not be set together")
-  }
-  
-  if (!is.null(area)){
-    categoryVar <- "areas"
-  }else{
-    categoryVar <- "links"
-  }
-  
-  if (is.null(mcYear)){
-    typeOfData <- "/mcAll"
-  }else{
-    typeOfData <- "/mcInd"
-  }
-  timeStepType <- paste("/hourly", categoryVar, sep = "/") 
-  nameStructure <- paste0(timeStepType, typeOfData, "/structure")
-  
-  H5locAntaresh5 <- rhdf5::H5Fopen(name = pathH5)
-  hourlyDataStructure <- rhdf5::h5read(H5locAntaresh5, name = nameStructure)
-  
-  if (!is.null(area)){
-    indexCateroryInstance <- grep(area, hourlyDataStructure$area)[1]
-  }else{
-    indexCateroryInstance <- grep(link, hourlyDataStructure$link)[1]
-  }
-  
-  indexAntVar <- grep(antVar, hourlyDataStructure$variable)[1]
-  indexTimeId <- timeId
-  if (is.null(mcYear)){
-    indexMcYear <- 1
-  }else{
-    indexMcYear <- grep(mcYear, hourlyDataStructure$mcYear)[1]
-  }
-  
-  listIndex <- list(indexTimeId, indexAntVar, indexCateroryInstance, indexMcYear)
-  #debug print(listIndex)
-  
-  hourlyData <- rhdf5::h5read(
-    H5locAntaresh5, 
-    name = paste0(timeStepType, typeOfData, "/data"),
-    index = listIndex)
-  
-  hourlyData[,,,] <- newValue
-  
-  rhdf5::h5writeDataset(
-    obj = hourlyData, 
-    h5loc = H5locAntaresh5, 
-    name = paste0(timeStepType, typeOfData, "/data"),
-    index = listIndex
-  )
-  
-  rhdf5::H5Fclose(h5file = H5locAntaresh5)
-  rhdf5::h5closeAll()
-}
+#' #' edit h5 file only for TEST 
+#' #' currently only for hourly data and areas
+#' #' 
+#' #' @param pathH5 path H5 file
+#' #' @param area character
+#' #' @param timeId timeId to change
+#' #' @param antVar antares Variable to change
+#' #' @param newValue the newValue
+#' #' 
+#' #' @noRd
+#' .h5Antares_edit_variable <- function(pathH5 = NULL, area = NULL, timeId = 1, antVar = NULL, newValue = NULL, mcYear = NULL, link = NULL){
+#'   
+#'   if (!is.null(area) & !is.null(link)){
+#'     stop("area and link must not be set together")
+#'   }
+#'   
+#'   if (!is.null(area)){
+#'     categoryVar <- "areas"
+#'   }else{
+#'     categoryVar <- "links"
+#'   }
+#'   
+#'   if (is.null(mcYear)){
+#'     typeOfData <- "/mcAll"
+#'   }else{
+#'     typeOfData <- "/mcInd"
+#'   }
+#'   timeStepType <- paste("/hourly", categoryVar, sep = "/") 
+#'   nameStructure <- paste0(timeStepType, typeOfData, "/structure")
+#'   
+#'   if (!is.null(area)){
+#'     indexCateroryInstance <- grep(area, hourlyDataStructure$area)[1]
+#'   }else{
+#'     indexCateroryInstance <- grep(link, hourlyDataStructure$link)[1]
+#'   }
+#'   
+#'   indexAntVar <- grep(antVar, hourlyDataStructure$variable)[1]
+#'   indexTimeId <- timeId
+#'   if (is.null(mcYear)){
+#'     indexMcYear <- 1
+#'   }else{
+#'     indexMcYear <- grep(mcYear, hourlyDataStructure$mcYear)[1]
+#'   }
+#'   
+#'   listIndex <- list(indexTimeId, indexAntVar, indexCateroryInstance, indexMcYear)
+#'   #debug print(listIndex)
+#' }
