@@ -10,4 +10,8 @@ $(function() {
     }
   });
   
-});
\ No newline at end of file
+});
+
+function updateShinyLanguage(lg) {
+  Shiny.onInputChange("language", lg);
+}
\ No newline at end of file
